#!/bin/bash
set -e
SOPIN="12345678"
USERPIN="12345678"
TOKENLABEL="CST-PHYTECDEVCA"
SLOT_INDEX=0

PKCS11TOOL="pkcs11-tool --slot-index=$SLOT_INDEX --module /usr/lib/softhsm/libsofthsm2.so -l --pin $USERPIN"

IMG_LABEL="IMG1_1_sha256_4096_65537_v3_usr"
CSF_LABEL="CSF1_1_sha256_4096_65537_v3_usr"
FIT_LABEL="FIT4096"
RAUC_LABEL="rauc-development-1"
KERNEL_MODSIGN_LABEL="kernel-modsign"

CSF_KEY="../../nxp_habv4_pki/keys/CSF1_1_sha256_4096_65537_v3_usr_key.pem"
CSF_CERT="../../nxp_habv4_pki/crts/CSF1_1_sha256_4096_65537_v3_usr_crt.pem"

IMG_KEY="../../nxp_habv4_pki/keys/IMG1_1_sha256_4096_65537_v3_usr_key.pem"
IMG_CERT="../../nxp_habv4_pki/crts/IMG1_1_sha256_4096_65537_v3_usr_crt.pem"

FIT_CERT="../../fit/FIT-4096.crt"
FIT_KEY="../../fit/FIT-4096.key"

RAUC_CERT="../../rauc-intermediate/development-1.cert.pem"
RAUC_KEY="../../rauc-intermediate/private/development-1.key.pem"

KERNEL_MODSIGN="../../kernel_modsign/kernel_modsign.pem"

#init token
pkcs11-tool --module /usr/lib/softhsm/libsofthsm2.so --slot-index=${SLOT_INDEX} --init-token --init-pin --so-pin=$SOPIN --new-pin=$USERPIN --label="${TOKENLABEL}" --pin=$USERPIN --login


openssl rsa -in "${CSF_KEY}" -outform DER -out CSF1_1_sha256_4096_65537_v3_usr_key.der
openssl rsa -in "${IMG_KEY}" -outform DER -out IMG1_1_sha256_4096_65537_v3_usr_key.der



openssl x509 -outform DER -in "${CSF_CERT}" -out CSF1_1_sha256_4096_65537_v3_usr_crt.der
openssl x509 -outform DER -in "${IMG_CERT}" -out IMG1_1_sha256_4096_65537_v3_usr_crt.der



$PKCS11TOOL --label="$CSF_LABEL" --write-object CSF1_1_sha256_4096_65537_v3_usr_key.der --type privkey --id 2222
$PKCS11TOOL --label="$CSF_LABEL" --write-object CSF1_1_sha256_4096_65537_v3_usr_crt.der --type cert --id 2222

$PKCS11TOOL --label="$IMG_LABEL" --write-object IMG1_1_sha256_4096_65537_v3_usr_key.der --type privkey --id 2223
$PKCS11TOOL --label="$IMG_LABEL" --write-object IMG1_1_sha256_4096_65537_v3_usr_crt.der --type cert --id 2223


$PKCS11TOOL --label="$FIT_LABEL" --write-object "${FIT_KEY}" --type privkey --id 2224
openssl x509 -pubkey -noout -in "${FIT_CERT}" > FIT-4096.pubkey
$PKCS11TOOL --label="$FIT_LABEL" --write-object FIT-4096.pubkey --type pubkey --id 2224


$PKCS11TOOL --label="$RAUC_LABEL" --write-object "$RAUC_CERT" --type cert --id 2225
openssl rsa -in "${RAUC_KEY}" -outform DER -out rauc-development-1-key.der
$PKCS11TOOL --label="$RAUC_LABEL" --write-object rauc-development-1-key.der --type privkey --id 2225

openssl x509 -outform DER -in "${KERNEL_MODSIGN}" -out kernel_modsign.der
$PKCS11TOOL --label="$KERNEL_MODSIGN_LABEL" --write-object kernel_modsign.der --type cert --id 2226
openssl rsa -in "${KERNEL_MODSIGN}" -outform DER -out kernel_modsign.key
$PKCS11TOOL --label="$KERNEL_MODSIGN_LABEL" --write-object kernel_modsign.key --type privkey --id 2226

